src/Config.hh
changeset 377 01d3c340b372
parent 311 440763821484
child 380 d193dd1d8a7e
--- a/src/Config.hh	Mon Dec 15 15:36:17 2008 +0000
+++ b/src/Config.hh	Mon Dec 15 16:41:00 2008 +0000
@@ -77,24 +77,33 @@
 const float PROJECTILE_START_DISTANCE = 10.0;
 
 /*
- * Rope
+ * @name Rope
+ * @{
  */
 
-// how much to grow the rope length by on every ROPE_UP/DOWN
+/** How much to grow the rope length by on every ROPE_UP/DOWN */
 const float ROPE_GROWTH_RATE = 5;
 
-// the force that the rope exerts on the player when the length is too long
+/** The force that the rope exerts on the player when the length is too long */
 const float ROPE_FORCE = 3500;
 
-// same as player mass...?
+/** Same as player mass...? */
 const float ROPE_MASS = 10.0;
 
 // initial length... this should probably be a bit more dynamic?
 const float ROPE_LENGTH = 100.0;
 
-// initial velocity of the rope when thrown
+/** Initial velocity of the rope when thrown */
 const float ROPE_VELOCITY = 500;
 
+/**
+ * Rope colors, it should alternate between these two
+ */
+const CL_Color ROPE_COLOR_LIGHT = CL_Color(198, 100, 2);
+const CL_Color ROPE_COLOR_DARK = CL_Color(159, 79, 1);
+
+// @}
+
 // Graphical properties
 const CL_Color COLOR_EMPTY(86, 41, 0);
 const CL_Color COLOR_DIRT(144, 82, 23);
@@ -77,24 +77,33 @@
 const float ROPE_MASS = 10.0;
 
-// initial length... this should probably be a bit more dynamic?
+/** Initial rope length... this should probably be a bit more dynamic? */
 const float ROPE_LENGTH = 100.0;
 